import React, { useState, useEffect } from 'react';
import { useParams, useNavigate } from 'react-router-dom';
import { Mail, Download } from 'lucide-react';
import { Match, Seat } from '../types';

export default function MatchDetailPage() {
  const { id } = useParams<{ id: string }>();
  const navigate = useNavigate();
  const [match, setMatch] = useState<Match | null>(null);
  const [seats, setSeats] = useState<Seat[]>([]);
  const [selectedSeats, setSelectedSeats] = useState<number[]>([]);
  const [formData, setFormData] = useState({
    name: '',
    email: '',
    phone: '',
    deliveryMethod: 'download' as 'download' | 'email'
  });
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    const fetchMatch = async () => {
      try {
        const response = await fetch(`/api/matches/${id}`);
        if (!response.ok) throw new Error('Failed to fetch match');
        const data = await response.json();
        setMatch(data);
      } catch (err) {
        setError(err instanceof Error ? err.message : 'Failed to fetch match');
      } finally {
        setLoading(false);
      }
    };

    const fetchSeats = async () => {
      try {
        const response = await fetch(`/api/tickets/match/${id}/seats`);
        if (!response.ok) throw new Error('Failed to fetch seats');
        const data = await response.json();
        setSeats(data);
      } catch (err) {
        setError(err instanceof Error ? err.message : 'Failed to fetch seats');
      }
    };

    fetchMatch();
    fetchSeats();
  }, [id]);

  const handleSeatClick = (seatNumber: number) => {
    setSelectedSeats(prev => {
      if (prev.includes(seatNumber)) {
        return prev.filter(s => s !== seatNumber);
      }
      return [...prev, seatNumber];
    });
  };

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    if (!match) return;

    try {
      const response = await fetch('/api/tickets', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({
          matchId: match.id,
          ...formData,
          selectedSeats
        }),
      });

      if (!response.ok) {
        throw new Error('Failed to create ticket');
      }

      const data = await response.json();
      
      if (formData.deliveryMethod === 'download') {
        // Create a temporary link element to trigger the download
        const link = document.createElement('a');
        link.href = data.pdfUrl;
        link.download = `ticket-${match.name}-${selectedSeats.join('-')}.pdf`;
        document.body.appendChild(link);
        link.click();
        document.body.removeChild(link);
      }
      
      navigate('/');
    } catch (err) {
      setError(err instanceof Error ? err.message : 'Failed to create ticket');
    }
  };

  if (loading) return <div>Loading...</div>;
  if (error) return <div>Error: {error}</div>;
  if (!match) return <div>Match not found</div>;

  return (
    <div className="container mx-auto px-4 py-8">
      <h1 className="text-3xl font-bold mb-6">{match.name}</h1>
      
      <div className="grid grid-cols-1 md:grid-cols-2 gap-8">
        <div>
          <div className="bg-gray-800 rounded-lg shadow-md p-6 mb-6 text-white">
            <h2 className="text-xl font-semibold mb-4">Match Details</h2>
            <p><strong>Date:</strong> {new Date(match.date).toLocaleString()}</p>
            <p><strong>Location:</strong> {match.location}</p>
            <p><strong>Available Seats:</strong> {match.availableSeats}</p>
            {match.price > 0 && <p><strong>Price:</strong> ${match.price}</p>}
            {match.timeoutDate && (
              <p><strong>Booking Deadline:</strong> {new Date(match.timeoutDate).toLocaleString()}</p>
            )}
          </div>

          <div className="bg-gray-800 rounded-lg shadow-md p-6 text-white">
            <h2 className="text-xl font-semibold mb-4">Select Seats</h2>
            <div className="grid grid-cols-2 sm:grid-cols-3 md:grid-cols-4 lg:grid-cols-6 xl:grid-cols-8 gap-6">
              {seats.map((seat) => (
                <button
                  key={seat.seatNumber}
                  onClick={() => handleSeatClick(seat.seatNumber)}
                  disabled={seat.status !== 'available'}
                  className={`p-3 rounded-md text-sm font-semibold transition-colors duration-200 flex items-center justify-center text-center w-full h-[60px] ${
                    seat.status === 'available'
                      ? selectedSeats.includes(seat.seatNumber)
                        ? 'bg-blue-600 hover:bg-blue-700 text-white'
                        : 'bg-gray-700 hover:bg-gray-600 text-gray-200'
                      : 'bg-red-800 cursor-not-allowed text-red-200 opacity-70'
                  }`}
                  title={seat.bookedBy ? `Booked by ${seat.bookedBy}` : undefined}
                >
                  {seat.direction ? (
                    <div className="flex items-center gap-2">
                      <span className="text-xs font-medium text-gray-300">{seat.direction}</span>
                      <span className="text-base">{seat.seatNumber}</span>
                    </div>
                  ) : (
                    <span>{`Seat ${seat.seatNumber}`}</span>
                  )}
                </button>
              ))}
            </div>
          </div>
        </div>

        <div className="bg-gray-800 rounded-lg shadow-md p-6 text-white">
          <h2 className="text-xl font-semibold mb-4">Book Tickets</h2>
          <form onSubmit={handleSubmit} className="space-y-4">
            <div>
              <label htmlFor="name" className="block text-sm font-medium text-gray-300">Name</label>
              <input
                type="text"
                id="name"
                value={formData.name}
                onChange={(e) => setFormData({ ...formData, name: e.target.value })}
                required
                className="mt-1 block w-full rounded-md border-gray-700 shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50 bg-gray-900 text-white"
              />
            </div>

            <div>
              <label htmlFor="email" className="block text-sm font-medium text-gray-300">Email</label>
              <input
                type="email"
                id="email"
                value={formData.email}
                onChange={(e) => setFormData({ ...formData, email: e.target.value })}
                required
                className="mt-1 block w-full rounded-md border-gray-700 shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50 bg-gray-900 text-white"
              />
            </div>

            <div>
              <label htmlFor="phone" className="block text-sm font-medium text-gray-300">Phone</label>
              <input
                type="tel"
                id="phone"
                value={formData.phone}
                onChange={(e) => setFormData({ ...formData, phone: e.target.value })}
                required
                className="mt-1 block w-full rounded-md border-gray-700 shadow-sm focus:border-blue-500 focus:ring focus:ring-blue-500 focus:ring-opacity-50 bg-gray-900 text-white"
              />
            </div>

            <div>
              <label className="block text-sm font-medium text-gray-300">Delivery Method</label>
              <div className="mt-2 space-y-2">
                <div className="flex items-center">
                  <input
                    type="radio"
                    id="download"
                    name="deliveryMethod"
                    value="download"
                    checked={formData.deliveryMethod === 'download'}
                    onChange={(e) => setFormData({ ...formData, deliveryMethod: e.target.value as 'download' | 'email' })}
                    className="focus:ring-blue-500 h-4 w-4 text-blue-600 border-gray-700 bg-gray-900"
                  />
                  <label htmlFor="download" className="ml-2 block text-sm text-gray-300 flex items-center gap-2">
                    <Download className="w-4 h-4 text-gray-300" />
                    Download
                  </label>
                </div>
                <div className="flex items-center">
                  <input
                    type="radio"
                    id="email"
                    name="deliveryMethod"
                    value="email"
                    checked={formData.deliveryMethod === 'email'}
                    onChange={(e) => setFormData({ ...formData, deliveryMethod: e.target.value as 'download' | 'email' })}
                    className="focus:ring-blue-500 h-4 w-4 text-blue-600 border-gray-700 bg-gray-900"
                  />
                  <label htmlFor="email" className="ml-2 block text-sm text-gray-300 flex items-center gap-2">
                    <Mail className="w-4 h-4 text-gray-300" />
                    Email
                  </label>
                </div>
              </div>
            </div>

            <button
              type="submit"
              disabled={selectedSeats.length === 0}
              className="w-full bg-blue-600 hover:bg-blue-700 text-white font-bold py-3 px-6 rounded-md transition-colors duration-200 disabled:opacity-50 disabled:cursor-not-allowed"
            >
              Book {selectedSeats.length} Seat{selectedSeats.length !== 1 ? 's' : ''}
              {match.price > 0 && ` - $${(match.price * selectedSeats.length).toFixed(2)}`}
            </button>
          </form>
        </div>
      </div>

      <footer className="mt-8 text-center text-gray-600">
        <p>Contact: <a href="mailto:alexandreyagoubi@gmail.com" className="text-blue-500 hover:underline">alexandreyagoubi@gmail.com</a></p>
      </footer>
    </div>
  );
}